@@ -102,8 +102,8 @@ kpColorCellsBase::kpColorCellsBase( QWidget *parent, int rows, int cols )
 
     setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
-    viewport()->setBackgroundRole( QPalette::Background );
-    setBackgroundRole( QPalette::Background );
+    viewport()->setBackgroundRole( QPalette::Window );
+    setBackgroundRole( QPalette::Window );
 }
 
 kpColorCellsBase::~kpColorCellsBase()
@@ -224,7 +224,7 @@ static void TableWidgetItemSetColor (QTableWidgetItem *tableItem, const QColor &
                 useColor = Qt::white;
             else
                 useColor = Qt::lightGray;
-                
+
             painter.fillRect(dx, dy, StippleSize, StippleSize, useColor);
         }
     }
@@ -461,8 +461,7 @@ void kpColorCellsBase::dragEnterEvent( QDragEnterEvent *event)
 #if DEBUG_KP_COLOR_CELLS_BASE
      qCDebug(kpLogMisc) << "kpColorCellsBase::dragEnterEvent() acceptDrags="
                << d->acceptDrags
-               << " canDecode=" << KColorMimeData::canDecode(event->mimeData())
-               << endl;
+               << " canDecode=" << KColorMimeData::canDecode(event->mimeData());
 #endif
      event->setAccepted( d->acceptDrags && KColorMimeData::canDecode( event->mimeData()));
      if (event->isAccepted ())
@@ -475,8 +474,7 @@ void kpColorCellsBase::dragMoveEvent (QDragMoveEvent *event)
 #if DEBUG_KP_COLOR_CELLS_BASE
      qCDebug(kpLogMisc) << "kpColorCellsBase::dragMoveEvent() acceptDrags="
                << d->acceptDrags
-               << " canDecode=" << KColorMimeData::canDecode(event->mimeData())
-               << endl;
+               << " canDecode=" << KColorMimeData::canDecode(event->mimeData());
 #endif
      // TODO: Disallow drag that isn't onto a cell.
      event->setAccepted( d->acceptDrags && KColorMimeData::canDecode( event->mimeData()));
@@ -549,8 +547,8 @@ void kpColorCellsBase::mouseReleaseEvent( QMouseEvent *e )
     d->inMouse = false;
     if (cell != -1)
     {
-	emit colorSelected( cell , color(cell) );
-	emit colorSelected( cell , color(cell), e->button() );
+        emit colorSelected( cell , color(cell) );
+        emit colorSelectedWhitButton( cell , color(cell), e->button() );
     }
 }
 
