@@ -30,15 +30,15 @@
 #include "kpMainWindow.h"
 #include "kpMainWindowPrivate.h"
 
-#include <qaction.h>
-#include <qdatastream.h>
+#include <QAction>
+#include <QDataStream>
 #include <QDesktopWidget>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QFileDialog>
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qsize.h>
+#include <QPainter>
+#include <QPixmap>
+#include <QSize>
 #include <QPrinter>
 #include <QPrintDialog>
 #include <QScreen>
@@ -107,31 +107,31 @@ void kpMainWindow::setupFileMenuActions ()
     d->actionExport = ac->addAction("file_export");
     d->actionExport->setText (i18n ("E&xport..."));
     d->actionExport->setIcon(KDE::icon("document-export"));
-    connect(d->actionExport, SIGNAL(triggered(bool)), SLOT (slotExport()));
+    connect (d->actionExport, &QAction::triggered, this, &kpMainWindow::slotExport);
 
     d->actionScan = ac->addAction("file_scan");
     d->actionScan->setText(i18n ("Scan..."));
     d->actionScan->setIcon(SmallIcon("scanner"));
 #if HAVE_KSANE
-    connect(d->actionScan, SIGNAL(triggered(bool)), SLOT(slotScan()));
+    connect (d->actionScan, &QAction::triggered, this, &kpMainWindow::slotScan);
 #else
     d->actionScan->setEnabled(false);
 #endif // HAVE_KSANE
 
     d->actionScreenshot = ac->addAction("file_screenshot");
     d->actionScreenshot->setText(i18n("Acquire Screenshot"));
-    connect(d->actionScreenshot, SIGNAL(triggered(bool)), SLOT(slotScreenshot()));
+    connect (d->actionScreenshot, &QAction::triggered, this, &kpMainWindow::slotScreenshot);
 
     d->actionProperties = ac->addAction ("file_properties");
     d->actionProperties->setText (i18n ("Properties"));
     d->actionProperties->setIcon(KDE::icon("document-properties"));
-    connect (d->actionProperties, SIGNAL (triggered(bool)), SLOT (slotProperties()));
+    connect (d->actionProperties, &QAction::triggered, this, &kpMainWindow::slotProperties);
 
     //d->actionRevert = KStandardAction::revert (this, SLOT (slotRevert()), ac);
     d->actionReload = ac->addAction ("file_revert");
     d->actionReload->setText (i18n ("Reloa&d"));
     d->actionReload->setIcon(KDE::icon("view-refresh"));
-    connect(d->actionReload, SIGNAL(triggered(bool)), SLOT (slotReload()));
+    connect (d->actionReload, &QAction::triggered, this, &kpMainWindow::slotReload);
     ac->setDefaultShortcuts (d->actionReload, KStandardShortcut::reload ());
     slotEnableReload ();
 
@@ -193,7 +193,7 @@ void kpMainWindow::addRecentURL (const QUrl &url_)
     //       To avoid the crash, make a copy of it before calling
     //       loadEntries() and use this copy, instead of the to-be-dangling
     //       ref.
-    const QUrl url = url_;
+    const QUrl& url = url_;
 
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::addRecentURL(" << url << ")";
@@ -232,10 +232,10 @@ void kpMainWindow::addRecentURL (const QUrl &url_)
     // TODO: Is this loop safe since a KMainWindow later along in the list,
     //       could be closed as the code in the body almost certainly re-enters
     //       the event loop?  Problem for KDE 3 as well, I think.
-    foreach (KMainWindow *kmw, KMainWindow::memberList ())
+    for (auto *kmw : KMainWindow::memberList ())
     {
         Q_ASSERT (dynamic_cast <kpMainWindow *> (kmw));
-        kpMainWindow *mw = static_cast <kpMainWindow *> (kmw);
+        auto *mw = dynamic_cast <kpMainWindow *> (kmw);
 
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\t\tmw=" << mw;
@@ -254,7 +254,7 @@ void kpMainWindow::addRecentURL (const QUrl &url_)
             mw->d->actionOpenRecent->loadEntries (cfg->group (kpSettingsGroupRecentFiles));
         #if DEBUG_KP_MAIN_WINDOW
             qCDebug(kpLogMainWindow) << "\t\t\tcheck recent URLs="
-                        << mw->d->actionOpenRecent->items () << endl;
+                        << mw->d->actionOpenRecent->items ();
         #endif
         }
     }
@@ -276,7 +276,7 @@ void kpMainWindow::slotNew ()
         // A document -- empty or otherwise -- is open.
         // Force open a new window.  In contrast, open() might not open
         // a new window in this case.
-        kpMainWindow *win = new kpMainWindow ();
+        auto *win = new kpMainWindow ();
         win->show ();
     }
     else
@@ -362,7 +362,7 @@ void kpMainWindow::setDocumentChoosingWindow (kpDocument *doc)
         !d->configOpenImagesInSameWindow)
     {
         // Send doc to new window.
-        kpMainWindow *win = new kpMainWindow (doc);
+        auto *win = new kpMainWindow (doc);
         win->show ();
     }
     else
@@ -385,9 +385,9 @@ kpDocument *kpMainWindow::openInternal (const QUrl &url,
         return nullptr;
 
     // Create/open doc.
-    kpDocument *newDoc = new kpDocument (fallbackDocSize.width (),
-                                         fallbackDocSize.height (),
-                                         documentEnvironment ());
+    auto *newDoc = new kpDocument (fallbackDocSize.width (),
+                                   fallbackDocSize.height (), documentEnvironment ());
+
     if (!newDoc->open (url, newDocSameNameIfNotExist))
     {
     #if DEBUG_KP_MAIN_WINDOW
@@ -414,7 +414,7 @@ bool kpMainWindow::open (const QUrl &url, bool newDocSameNameIfNotExist)
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::open(" << url
               << ",newDocSameNameIfNotExist=" << newDocSameNameIfNotExist
-              << ")" << endl;
+              << ")";
 #endif
 
     kpDocument *newDoc = openInternal (url,
@@ -426,10 +426,8 @@ bool kpMainWindow::open (const QUrl &url, bool newDocSameNameIfNotExist)
             addRecentURL (url);
         return true;
     }
-    else
-    {
-        return false;
-    }
+
+    return false;
 }
 
 //---------------------------------------------------------------------
@@ -440,10 +438,11 @@ QList<QUrl> kpMainWindow::askForOpenURLs(const QString &caption, bool allowMulti
   QMimeDatabase db;
   QStringList filterList;
   QString filter;
-  foreach(const QByteArray &type, QImageReader::supportedMimeTypes())
+  for (const auto &type : QImageReader::supportedMimeTypes())
   {
-    if ( !filter.isEmpty() )
+    if ( !filter.isEmpty() ) {
       filter += QLatin1Char(' ');
+    }
 
     QMimeType mime(db.mimeTypeForName(QString::fromLatin1(type)));
     if ( mime.isValid() )
@@ -467,13 +466,15 @@ QList<QUrl> kpMainWindow::askForOpenURLs(const QString &caption, bool allowMulti
   fd.setOption(QFileDialog::HideNameFilterDetails);
   fd.setWindowTitle(caption);
 
-  if ( allowMultipleURLs )
+  if ( allowMultipleURLs ) {
     fd.setFileMode(QFileDialog::ExistingFiles);
+  }
 
-  if ( fd.exec() )
+  if ( fd.exec() ) {
     return fd.selectedUrls();
-  else
-    return QList<QUrl>();
+  }
+
+  return QList<QUrl>();
 }
 
 //---------------------------------------------------------------------
@@ -485,11 +486,9 @@ void kpMainWindow::slotOpen ()
 
     const QList<QUrl> urls = askForOpenURLs(i18nc("@title:window", "Open Image"));
 
-    for (QList<QUrl>::const_iterator it = urls.begin ();
-         it != urls.end ();
-         ++it)
+    for (const auto & url : urls)
     {
-        open (*it);
+        open (url);
     }
 }
 
@@ -556,8 +555,7 @@ void kpMainWindow::slotScan ()
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tcreated scanDialog=" << d->scanDialog;
     #endif
-        connect (d->scanDialog, SIGNAL (finalImage(QImage,int)),
-                 SLOT (slotScanned(QImage,int)));
+        connect (d->scanDialog, &SaneDialog::finalImage, this, &kpMainWindow::slotScanned);
     }
 
 
@@ -575,8 +573,9 @@ void kpMainWindow::slotScan ()
     // scan dialogs are shown.  We don't do this between KScanDialog::setup()
     // and KScanDialog::exec() as it could be confusing alternating between
     // scanning and KolourPaint dialogs.
-    if (!shouldOpen ())
+    if (!shouldOpen ()) {
         return;
+    }
 
 
 #if DEBUG_KP_MAIN_WINDOW
@@ -644,8 +643,7 @@ void kpMainWindow::slotScanned (const QImage &image, int)
     kpDocument::getDataFromImage(image, saveOptions, metaInfo);
 
     // Create document from image and meta info.
-    kpDocument *doc = new kpDocument (image.width (), image.height (),
-                                      documentEnvironment ());
+    auto *doc = new kpDocument (image.width (), image.height (), documentEnvironment ());
     doc->setImage (image);
     doc->setSaveOptions (saveOptions);
     doc->setMetaInfo (metaInfo);
@@ -661,22 +659,22 @@ void kpMainWindow::slotScreenshot()
 {
   toolEndShape();
 
-  QDialog *dialog = new QDialog(this);
-  QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok |
+  auto *dialog = new QDialog(this);
+  auto *buttons = new QDialogButtonBox(QDialogButtonBox::Ok |
                                                    QDialogButtonBox::Cancel, dialog);
-  connect (buttons, SIGNAL (accepted()), dialog, SLOT (accept()));
-  connect (buttons, SIGNAL (rejected()), dialog, SLOT (reject()));
+  connect (buttons, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
+  connect (buttons, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
 
-  QLabel *label = new QLabel(i18n("Snapshot Delay"));
-  KPluralHandlingSpinBox *seconds = new KPluralHandlingSpinBox;
+  auto *label = new QLabel(i18n("Snapshot Delay"));
+  auto *seconds = new KPluralHandlingSpinBox;
   seconds->setRange(0, 99);
   seconds->setSuffix(ki18np(" second", " seconds"));
   seconds->setSpecialValueText(i18n("No delay"));
 
-  QCheckBox *hideWindow = new QCheckBox(i18n("Hide Main Window"));
+  auto *hideWindow = new QCheckBox(i18n("Hide Main Window"));
   hideWindow->setChecked(true);
 
-  QVBoxLayout *vbox = new QVBoxLayout(dialog);
+  auto *vbox = new QVBoxLayout(dialog);
   vbox->addWidget(label);
   vbox->addWidget(seconds);
   vbox->addWidget(hideWindow);
@@ -688,8 +686,9 @@ void kpMainWindow::slotScreenshot()
     return;
   }
 
-  if ( hideWindow->isChecked() )
+  if ( hideWindow->isChecked() ) {
     hide();
+  }
 
   // at least 1 seconds to make sure the window is hidden and the hide effect already stopped
   QTimer::singleShot((seconds->value() + 1) * 1000, this, SLOT(slotMakeScreenshot()));
@@ -704,7 +703,7 @@ void kpMainWindow::slotMakeScreenshot()
   QCoreApplication::processEvents();
   QPixmap pixmap = QGuiApplication::primaryScreen()->grabWindow(QApplication::desktop()->winId());
 
-  kpDocument *doc = new kpDocument(pixmap.width(), pixmap.height(), documentEnvironment());
+  auto *doc = new kpDocument(pixmap.width(), pixmap.height(), documentEnvironment());
   doc->setImage(pixmap.toImage());
 
   // Send document to current or new window.
@@ -748,17 +747,15 @@ bool kpMainWindow::save (bool localOnly)
     {
         return saveAs (localOnly);
     }
-    else
+
+    if (d->document->save (false/*no overwrite prompt*/,
+                           !d->document->savedAtLeastOnceBefore ()/*lossy prompt*/))
     {
-        if (d->document->save (false/*no overwrite prompt*/,
-                              !d->document->savedAtLeastOnceBefore ()/*lossy prompt*/))
-        {
-            addRecentURL (d->document->url ());
-            return true;
-        }
-        else
-            return false;
+        addRecentURL (d->document->url ());
+        return true;
     }
+
+    return false;
 }
 
 //---------------------------------------------------------------------
@@ -806,30 +803,34 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     KConfigGroup cfg (KSharedConfig::openConfig (), forcedSaveOptionsGroup);
 
 
-    if (chosenSaveOptions)
+    if (chosenSaveOptions) {
         *chosenSaveOptions = kpDocumentSaveOptions ();
+    }
 
-    if (allowOverwritePrompt)
+    if (allowOverwritePrompt) {
         *allowOverwritePrompt = true;  // play it safe for now
+    }
 
-    if (allowLossyPrompt)
+    if (allowLossyPrompt) {
         *allowLossyPrompt = true;  // play it safe for now
+    }
 
 
     kpDocumentSaveOptions fdSaveOptions = startSaveOptions;
 
     QStringList mimeTypes;
-    foreach(const QByteArray &type, QImageWriter::supportedMimeTypes())
+    for (const auto &type : QImageWriter::supportedMimeTypes()) {
       mimeTypes << QString::fromLatin1(type);
+    }
 #if DEBUG_KP_MAIN_WINDOW
     QStringList sortedMimeTypes = mimeTypes;
     sortedMimeTypes.sort ();
     qCDebug(kpLogMainWindow) << "\tmimeTypes=" << mimeTypes
-               << "\tsortedMimeTypes=" << sortedMimeTypes << endl;
+               << "\tsortedMimeTypes=" << sortedMimeTypes;
 #endif
     if (mimeTypes.isEmpty ())
     {
-        qCCritical(kpLogMainWindow) << "No output mimetypes!" << endl;
+        qCCritical(kpLogMainWindow) << "No output mimetypes!";
         return QUrl ();
     }
 
@@ -839,7 +840,7 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     {
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tmimeType=" << fdSaveOptions.mimeType ()
-                   << " not valid, get default" << endl;
+                   << " not valid, get default";
     #endif
 
         SETUP_READ_CFG ();
@@ -851,14 +852,17 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
         {
         #if DEBUG_KP_MAIN_WINDOW
             qCDebug(kpLogMainWindow) << "\tmimeType=" << fdSaveOptions.mimeType ()
-                       << " not valid, get hardcoded" << endl;
+                       << " not valid, get hardcoded";
         #endif
-            if (mimeTypes.contains ("image/png"))
+            if (mimeTypes.contains ("image/png")) {
                 fdSaveOptions.setMimeType ("image/png");
-            else if (mimeTypes.contains ("image/bmp"))
+            }
+            else if (mimeTypes.contains ("image/bmp")) {
                 fdSaveOptions.setMimeType ("image/bmp");
-            else
+            }
+            else {
                 fdSaveOptions.setMimeType (mimeTypes.first ());
+            }
         }
     }
 #undef MIME_TYPE_IS_VALID
@@ -881,7 +885,7 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     fdSaveOptions.printDebug ("\tcorrected saveOptions passed to fileDialog");
 #endif
 
-    kpDocumentSaveOptionsWidget *saveOptionsWidget =
+    auto *saveOptionsWidget =
         new kpDocumentSaveOptionsWidget (imageToBeSaved,
             fdSaveOptions,
             docMetaInfo,
@@ -893,11 +897,12 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     fd.setWindowTitle (caption);
     fd.setOperationMode (KFileDialog::Saving);
     fd.setMimeFilter (mimeTypes, fdSaveOptions.mimeType ());
-    if (localOnly)
+    if (localOnly) {
         fd.setMode (KFile::File | KFile::LocalOnly);
+    }
 
-    connect (&fd, SIGNAL (filterChanged(QString)),
-             saveOptionsWidget, SLOT (setMimeType(QString)));
+    connect (&fd, &KFileDialog::filterChanged,
+             saveOptionsWidget, &kpDocumentSaveOptionsWidget::setMimeType);
 
     if ( fd.exec() == QDialog::Accepted )
     {
@@ -914,8 +919,9 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
         cfg.sync ();
 
 
-        if (chosenSaveOptions)
+        if (chosenSaveOptions) {
             *chosenSaveOptions = newSaveOptions;
+        }
 
 
         bool shouldAllowOverwritePrompt =
@@ -951,8 +957,8 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     #endif
         return fd.selectedUrl ();
     }
-    else
-        return QUrl ();
+
+    return QUrl ();
 #undef SETUP_READ_CFG
 }
 
@@ -976,8 +982,9 @@ bool kpMainWindow::saveAs (bool localOnly)
                                     &allowLossyPrompt);
 
 
-    if (chosenURL.isEmpty ())
+    if (chosenURL.isEmpty ()) {
         return false;
+    }
 
 
     if (!d->document->saveAs (chosenURL, chosenSaveOptions,
@@ -1025,8 +1032,9 @@ bool kpMainWindow::slotExport ()
                                     &allowLossyPrompt);
 
 
-    if (chosenURL.isEmpty ())
+    if (chosenURL.isEmpty ()) {
         return false;
+    }
 
     if (!kpDocument::savePixmapToFile (d->document->imageWithSelection (),
                                        chosenURL,
@@ -1095,8 +1103,9 @@ bool kpMainWindow::slotReload ()
                          KGuiItem(i18n ("&Reload")));
         }
 
-        if (result != KMessageBox::Continue)
+        if (result != KMessageBox::Continue) {
             return false;
+        }
     }
 
 
@@ -1150,15 +1159,15 @@ void kpMainWindow::sendDocumentNameToPrinter (QPrinter *printer)
         dot = fileName.lastIndexOf ('.');
 
         // file.ext but not .hidden-file?
-        if (dot > 0)
+        if (dot > 0) {
             fileName.truncate (dot);
+        }
 
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "kpMainWindow::sendDocumentNameToPrinter() fileName="
                    << fileName
                    << " dir="
-                   << url.directory ()
-                   << endl;
+                   << url.path();
     #endif
         printer->setDocName (fileName);
     }
@@ -1181,17 +1190,14 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
 
 
     // Get image DPI.
-    double imageDotsPerMeterX =
-        double (d->document->metaInfo ()->dotsPerMeterX ());
-    double imageDotsPerMeterY =
-        double (d->document->metaInfo ()->dotsPerMeterY ());
+    auto imageDotsPerMeterX = double (d->document->metaInfo ()->dotsPerMeterX ());
+    auto imageDotsPerMeterY = double (d->document->metaInfo ()->dotsPerMeterY ());
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::sendImageToPrinter() image:"
                << " width=" << image.width ()
                << " height=" << image.height ()
                << " dotsPerMeterX=" << imageDotsPerMeterX
-               << " dotsPerMeterY=" << imageDotsPerMeterY
-               << endl;
+               << " dotsPerMeterY=" << imageDotsPerMeterY;
 #endif
 
     // Image DPI invalid (e.g. new image, could not read from file
@@ -1221,8 +1227,8 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
         // TODO: mysteriously, someone else is setting this to 96dpi always.
         QPixmap arbitraryScreenElement(1, 1);
         const QPaintDevice *screenDevice = &arbitraryScreenElement;
-        const int dpiX = screenDevice->logicalDpiX (),
-            dpiY = screenDevice->logicalDpiY ();
+        const auto dpiX = screenDevice->logicalDpiX ();
+        const auto dpiY = screenDevice->logicalDpiY ();
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tusing screen dpi: x=" << dpiX << " y=" << dpiY;
     #endif
@@ -1239,18 +1245,16 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
     //     m   m       m = margin
     //     m   m
     //     mmmmm
-    const int printerWidthMM = printer->widthMM ();
-    const int printerHeightMM = printer->heightMM ();
+    const auto printerWidthMM = printer->widthMM ();
+    const auto printerHeightMM = printer->heightMM ();
+
+    auto dpiX = imageDotsPerMeterX / KP_INCHES_PER_METER;
+    auto dpiY = imageDotsPerMeterY / KP_INCHES_PER_METER;
+
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\tprinter: widthMM=" << printerWidthMM
-               << " heightMM=" << printerHeightMM
-               << endl;
-#endif
+               << " heightMM=" << printerHeightMM;
 
-
-    double dpiX = imageDotsPerMeterX / KP_INCHES_PER_METER;
-    double dpiY = imageDotsPerMeterY / KP_INCHES_PER_METER;
-#if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\timage: dpiX=" << dpiX << " dpiY=" << dpiY;
 #endif
 
@@ -1259,17 +1263,15 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
     // If image doesn't fit on page at intended DPI, change the DPI.
     //
 
-    const double scaleDpiX =
-        (image.width () / (printerWidthMM / KP_MILLIMETERS_PER_INCH))
-            / dpiX;
-    const double scaleDpiY =
-        (image.height () / (printerHeightMM / KP_MILLIMETERS_PER_INCH))
-            / dpiY;
-    const double scaleDpi = qMax (scaleDpiX, scaleDpiY);
+    const auto scaleDpiX =
+        (image.width () / (printerWidthMM / KP_MILLIMETERS_PER_INCH)) / dpiX;
+    const auto scaleDpiY =
+        (image.height () / (printerHeightMM / KP_MILLIMETERS_PER_INCH)) / dpiY;
+    const auto scaleDpi = qMax (scaleDpiX, scaleDpiY);
+
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\t\tscaleDpi: x=" << scaleDpiX << " y=" << scaleDpiY
-               << " --> scale at " << scaleDpi << " to fit?"
-               << endl;
+               << " --> scale at " << scaleDpi << " to fit?";
 #endif
 
     // Need to increase resolution to fit page?
@@ -1279,7 +1281,7 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
         dpiY *= scaleDpi;
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\t\t\tto fit page, scaled to:"
-                   << " dpiX=" << dpiX << " dpiY=" << dpiY << endl;
+                   << " dpiX=" << dpiX << " dpiY=" << dpiY;
     #endif
     }
 
@@ -1293,7 +1295,7 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
     {
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tdpiX > dpiY; stretching image height to equalise DPIs to dpiX="
-                   << dpiX << endl;
+                   << dpiX;
     #endif
         kpPixmapFX::scale (&image,
              image.width (),
@@ -1306,7 +1308,7 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
     {
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tdpiY > dpiX; stretching image width to equalise DPIs to dpiY="
-                   << dpiY << endl;
+                   << dpiY;
     #endif
         kpPixmapFX::scale (&image,
              qMax (1, qRound (image.width () * dpiY / dpiX)),
@@ -1328,7 +1330,7 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
 
     if (showPrinterSetupDialog)
     {
-        kpPrintDialogPage *optionsPage = new kpPrintDialogPage (this);
+        auto *optionsPage = new kpPrintDialogPage (this);
         optionsPage->setPrintImageCenteredOnPage (d->configPrintImageCenteredOnPage);
 
         QPrintDialog *printDialog =
@@ -1355,8 +1357,9 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
 
         delete printDialog;
 
-        if (!wantToPrint)
+        if (!wantToPrint) {
             return;
+        }
     }
 
 
@@ -1451,8 +1454,9 @@ bool kpMainWindow::queryCloseDocument ()
 {
     toolEndShape ();
 
-    if (!d->document || !d->document->isModified ())
+    if (!d->document || !d->document->isModified ()) {
         return true;  // ok to close current doc
+    }
 
     int result = KMessageBox::warningYesNoCancel (this,
                      i18n ("The document \"%1\" has been modified.\n"
@@ -1482,11 +1486,13 @@ bool kpMainWindow::queryClose ()
 #endif
     toolEndShape ();
 
-    if (!queryCloseDocument ())
+    if (!queryCloseDocument ()) {
         return false;
+    }
 
-    if (!queryCloseColors ())
+    if (!queryCloseColors ()) {
         return false;
+    }
 
     return true;
 }
@@ -1498,8 +1504,9 @@ void kpMainWindow::slotClose ()
 {
     toolEndShape ();
 
-    if (!queryCloseDocument ())
+    if (!queryCloseDocument ()) {
         return;
+    }
 
     setDocument (nullptr);
 }
