@@ -55,37 +55,39 @@ void kpMainWindow::setupTextToolBarActions ()
 
     d->actionTextFontFamily = ac->add<KFontAction> ("text_font_family");
     d->actionTextFontFamily->setText (i18n ("Font Family"));
-    connect (d->actionTextFontFamily, SIGNAL (triggered(QString)),
-             this, SLOT (slotTextFontFamilyChanged()));
+    connect (d->actionTextFontFamily,
+             static_cast<void (KFontAction::*)(const QString&)>(&KFontAction::triggered),
+             this, &kpMainWindow::slotTextFontFamilyChanged);
 
     d->actionTextFontSize = ac->add<KFontSizeAction> ("text_font_size");
     d->actionTextFontSize->setText (i18n ("Font Size"));
-    connect (d->actionTextFontSize, SIGNAL (fontSizeChanged(int)),
-             this, SLOT (slotTextFontSizeChanged()));
+    connect (d->actionTextFontSize,
+             static_cast<void (KFontSizeAction::*)(int)>(&KFontSizeAction::triggered),
+             this, &kpMainWindow::slotTextFontSizeChanged);
 
     d->actionTextBold = ac->add<KToggleAction> ("text_bold");
     d->actionTextBold->setIcon(KDE::icon("format-text-bold"));
     d->actionTextBold->setText (i18n ("Bold"));
-    connect (d->actionTextBold, SIGNAL (triggered(bool)),
-        SLOT (slotTextBoldChanged()));
+    connect (d->actionTextBold, &KToggleAction::triggered,
+             this, &kpMainWindow::slotTextBoldChanged);
 
     d->actionTextItalic = ac->add<KToggleAction> ("text_italic");
     d->actionTextItalic->setIcon (KDE::icon("format-text-italic"));
     d->actionTextItalic->setText (i18n ("Italic"));
-    connect (d->actionTextItalic, SIGNAL (triggered(bool)),
-        SLOT (slotTextItalicChanged()));
+    connect (d->actionTextItalic, &KToggleAction::triggered,
+             this, &kpMainWindow::slotTextItalicChanged);
 
     d->actionTextUnderline = ac->add<KToggleAction> ("text_underline");
     d->actionTextUnderline->setIcon (KDE::icon("format-text-underline"));
     d->actionTextUnderline->setText (i18n ("Underline"));
-    connect (d->actionTextUnderline, SIGNAL (triggered(bool)),
-        SLOT (slotTextUnderlineChanged()));
+    connect (d->actionTextUnderline, &KToggleAction::triggered,
+             this, &kpMainWindow::slotTextUnderlineChanged);
 
     d->actionTextStrikeThru = ac->add<KToggleAction> ("text_strike_thru");
     d->actionTextStrikeThru->setIcon(KDE::icon("format-text-strikethrough"));
     d->actionTextStrikeThru->setText (i18n ("Strike Through"));
-    connect (d->actionTextStrikeThru, SIGNAL (triggered(bool)),
-        SLOT (slotTextStrikeThruChanged()));
+    connect (d->actionTextStrikeThru, &KToggleAction::triggered,
+             this, &kpMainWindow::slotTextStrikeThruChanged);
 
 
     readAndApplyTextSettings ();
@@ -152,12 +154,12 @@ void kpMainWindow::slotTextFontFamilyChanged ()
                << "fontFamily="
                << d->actionTextFontFamily->font ()
                << "action.currentItem="
-               << d->actionTextFontFamily->currentItem ()
-               << endl;
+               << d->actionTextFontFamily->currentItem ();
 #endif
 
-    if (!d->isFullyConstructed)
+    if (!d->isFullyConstructed) {
         return;
+    }
 
     if (d->toolText && d->toolText->hasBegun ())
     {
@@ -168,8 +170,9 @@ void kpMainWindow::slotTextFontFamilyChanged ()
 
     // Since editable KSelectAction's steal focus from view, switch back to mainView
     // TODO: back to the last view
-    if (d->mainView)
+    if (d->mainView) {
         d->mainView->setFocus ();
+    }
 
     KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupText);
     cfg.writeEntry (kpSettingFontFamily, d->actionTextFontFamily->font ());
@@ -185,12 +188,12 @@ void kpMainWindow::slotTextFontSizeChanged ()
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotTextFontSizeChanged() alive="
                << d->isFullyConstructed
                << " fontSize="
-               << d->actionTextFontSize->fontSize ()
-               << endl;
+               << d->actionTextFontSize->fontSize ();
 #endif
 
-    if (!d->isFullyConstructed)
+    if (!d->isFullyConstructed) {
         return;
+    }
 
     if (d->toolText && d->toolText->hasBegun ())
     {
@@ -201,8 +204,9 @@ void kpMainWindow::slotTextFontSizeChanged ()
 
     // Since editable KSelectAction's steal focus from view, switch back to mainView
     // TODO: back to the last view
-    if (d->mainView)
+    if (d->mainView) {
         d->mainView->setFocus ();
+    }
 
     KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupText);
     cfg.writeEntry (kpSettingFontSize, d->actionTextFontSize->fontSize ());
@@ -218,12 +222,12 @@ void kpMainWindow::slotTextBoldChanged ()
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotTextFontBoldChanged() alive="
                << d->isFullyConstructed
                << " bold="
-               << d->actionTextBold->isChecked ()
-               << endl;
+               << d->actionTextBold->isChecked ();
 #endif
 
-    if (!d->isFullyConstructed)
+    if (!d->isFullyConstructed) {
         return;
+    }
 
     if (d->toolText && d->toolText->hasBegun ())
     {
@@ -243,12 +247,12 @@ void kpMainWindow::slotTextItalicChanged ()
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotTextFontItalicChanged() alive="
                << d->isFullyConstructed
                << " bold="
-               << d->actionTextItalic->isChecked ()
-               << endl;
+               << d->actionTextItalic->isChecked ();
 #endif
 
-    if (!d->isFullyConstructed)
+    if (!d->isFullyConstructed) {
         return;
+    }
 
     if (d->toolText && d->toolText->hasBegun ())
     {
@@ -268,12 +272,12 @@ void kpMainWindow::slotTextUnderlineChanged ()
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotTextFontUnderlineChanged() alive="
                << d->isFullyConstructed
                << " underline="
-               << d->actionTextUnderline->isChecked ()
-               << endl;
+               << d->actionTextUnderline->isChecked ();
 #endif
 
-    if (!d->isFullyConstructed)
+    if (!d->isFullyConstructed) {
         return;
+    }
 
     if (d->toolText && d->toolText->hasBegun ())
     {
@@ -293,12 +297,12 @@ void kpMainWindow::slotTextStrikeThruChanged ()
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotTextStrikeThruChanged() alive="
                << d->isFullyConstructed
                << " strikeThru="
-               << d->actionTextStrikeThru->isChecked ()
-               << endl;
+               << d->actionTextStrikeThru->isChecked ();
 #endif
 
-    if (!d->isFullyConstructed)
+    if (!d->isFullyConstructed) {
         return;
+    }
 
     if (d->toolText && d->toolText->hasBegun ())
     {
