@@ -31,12 +31,12 @@
 
 #include "kpPixmapFX.h"
 
-#include <math.h>
+#include <QtMath>
 
-#include <qpainter.h>
+#include <QPainter>
 #include <QImage>
-#include <qpoint.h>
-#include <qrect.h>
+#include <QPoint>
+#include <QRect>
 
 #include "kpLogCategories.h"
 
@@ -54,20 +54,23 @@ void kpPixmapFX::resize (QImage *destPtr, int w, int h,
     qCDebug(kpLogPixmapfx) << "kpPixmapFX::resize()";
 #endif
 
-    if (!destPtr)
+    if (!destPtr) {
         return;
+    }
 
     const int oldWidth = destPtr->width ();
     const int oldHeight = destPtr->height ();
 
-    if (w == oldWidth && h == oldHeight)
+    if (w == oldWidth && h == oldHeight) {
         return;
+    }
 
     QImage newImage (w, h, QImage::Format_ARGB32_Premultiplied);
 
     // Would have new undefined areas?
-    if (w > oldWidth || h > oldHeight)
+    if (w > oldWidth || h > oldHeight) {
         newImage.fill (backgroundColor.toQRgb ());
+    }
 
     // Copy over old pixmap.
     QPainter painter(&newImage);
@@ -95,8 +98,9 @@ QImage kpPixmapFX::resize (const QImage &image, int w, int h,
 // public static
 void kpPixmapFX::scale (QImage *destPtr, int w, int h, bool pretty)
 {
-    if (!destPtr)
+    if (!destPtr) {
         return;
+    }
 
     *destPtr = kpPixmapFX::scale (*destPtr, w, h, pretty);
 }
@@ -111,12 +115,12 @@ QImage kpPixmapFX::scale (const QImage &image, int w, int h, bool pretty)
                << ",w=" << w
                << ",h=" << h
                << ",pretty=" << pretty
-               << ")"
-               << endl;
+               << ")";
 #endif
 
-    if (w == image.width () && h == image.height ())
+    if (w == image.width () && h == image.height ()) {
         return image;
+    }
 
     return image.scaled(w, h, Qt::IgnoreAspectRatio,
                         pretty ? Qt::SmoothTransformation : Qt::FastTransformation);
@@ -126,11 +130,11 @@ QImage kpPixmapFX::scale (const QImage &image, int w, int h, bool pretty)
 
 // public static
 const double kpPixmapFX::AngleInDegreesEpsilon =
-    KP_RADIANS_TO_DEGREES (atan (1.0 / 10000.0))
+    qRadiansToDegrees (std::tan (1.0 / 10000.0))
         / (2.0/*max error allowed*/ * 2.0/*for good measure*/);
 
 
-static void MatrixDebug (const QString matrixName, const QMatrix &matrix,
+static void MatrixDebug (const QString& matrixName, const QTransform &matrix,
         int srcPixmapWidth = -1, int srcPixmapHeight = -1)
 {
 #if DEBUG_KP_PIXMAP_FX
@@ -150,18 +154,6 @@ static void MatrixDebug (const QString matrixName, const QMatrix &matrix,
         qCDebug(kpLogPixmapfx) << "(w-1,h-1) ->" << matrix.map (QPoint (w - 1, h - 1));
     }
 
-#if 0
-    QMatrix trueMatrix = QPixmap::trueMatrix (matrix, w, h);
-    qCDebug(kpLogPixmapfx) << matrixName << "trueMatrix=" << trueMatrix;
-    if (w > 0 && h > 0)
-    {
-        qCDebug(kpLogPixmapfx) << "(0,0) ->" << trueMatrix.map (QPoint (0, 0));
-        qCDebug(kpLogPixmapfx) << "(w-1,0) ->" << trueMatrix.map (QPoint (w - 1, 0));
-        qCDebug(kpLogPixmapfx) << "(0,h-1) ->" << trueMatrix.map (QPoint (0, h - 1));
-        qCDebug(kpLogPixmapfx) << "(w-1,h-1) ->" << trueMatrix.map (QPoint (w - 1, h - 1));
-    }
-#endif
-
 #else
 
     Q_UNUSED (matrixName);
@@ -188,7 +180,7 @@ static void MatrixDebug (const QString matrixName, const QMatrix &matrix,
 //       the output is the same as QPixmap::trueMatrix(): <dy> is one off
 //       (dy=27 instead of 26).
 //       SYNC: I bet this is a Qt4 bug.
-static QMatrix MatrixWithZeroOrigin (const QMatrix &matrix, int width, int height)
+static QTransform MatrixWithZeroOrigin (const QTransform &matrix, int width, int height)
 {
 #if DEBUG_KP_PIXMAP_FX
     qCDebug(kpLogPixmapfx) << "matrixWithZeroOrigin(w=" << width << ",h=" << height << ")";
@@ -205,7 +197,7 @@ static QMatrix MatrixWithZeroOrigin (const QMatrix &matrix, int width, int heigh
     qCDebug(kpLogPixmapfx) << "\tmappedRect=" << mappedRect;
 #endif
 
-    QMatrix translatedMatrix (
+    QTransform translatedMatrix (
         matrix.m11 (), matrix.m12 (),
         matrix.m21 (), matrix.m22 (),
         matrix.dx () - mappedRect.left (), matrix.dy () - mappedRect.top ());
@@ -235,22 +227,23 @@ static double TrueMatrixEpsilon = 0.000001;
 // QPainter::SmoothPixmapTransform is disabled.
 static double TrueMatrixFixInts (double x)
 {
-    if (fabs (x - qRound (x)) < TrueMatrixEpsilon)
+    if (std::fabs (x - qRound (x)) < TrueMatrixEpsilon) {
         return qRound (x);
-    else
-        return x;
+    }
+
+    return x;
 }
 
 //---------------------------------------------------------------------
 
-static QMatrix TrueMatrix (const QMatrix &matrix, int srcPixmapWidth, int srcPixmapHeight)
+static QTransform TrueMatrix (const QTransform &matrix, int srcPixmapWidth, int srcPixmapHeight)
 {
     ::MatrixDebug ("TrueMatrix(): org", matrix);
-    
-    const QMatrix truMat = QPixmap::trueMatrix (matrix, srcPixmapWidth, srcPixmapHeight);
+
+    const QTransform truMat = QPixmap::trueMatrix (matrix, srcPixmapWidth, srcPixmapHeight);
     ::MatrixDebug ("TrueMatrix(): passed through QPixmap::trueMatrix()", truMat);
 
-    const QMatrix retMat (
+    const QTransform retMat (
         ::TrueMatrixFixInts (truMat.m11 ()),
         ::TrueMatrixFixInts (truMat.m12 ()),
         ::TrueMatrixFixInts (truMat.m21 ()),
@@ -265,7 +258,7 @@ static QMatrix TrueMatrix (const QMatrix &matrix, int srcPixmapWidth, int srcPix
 //---------------------------------------------------------------------
 
 // Like QPixmap::transformed() but fills new areas with <backgroundColor>
-// (unless <backgroundColor> is invalid) and works around internal QMatrix
+// (unless <backgroundColor> is invalid) and works around internal QTransform
 // floating point -> integer oddities, that would otherwise give fatally
 // incorrect results.  If you don't believe me on this latter point, compare
 // QPixmap::transformed() to us using a flip matrix or a rotate-by-multiple-of-90
@@ -275,18 +268,17 @@ static QMatrix TrueMatrix (const QMatrix &matrix, int srcPixmapWidth, int srcPix
 //
 // Use <targetWidth> and <targetHeight> to specify the intended output size
 // of the pixmap.  -1 if don't care.
-static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_,
+static QImage TransformPixmap (const QImage &pm, const QTransform &transformMatrix_,
         const kpColor &backgroundColor,
         int targetWidth, int targetHeight)
 {
-    QMatrix transformMatrix = transformMatrix_;
+    QTransform transformMatrix = transformMatrix_;
 
 #if DEBUG_KP_PIXMAP_FX && 1
     qCDebug(kpLogPixmapfx) << "kppixmapfx.cpp: TransformPixmap(pm.size=" << pm.size ()
                << ",targetWidth=" << targetWidth
                << ",targetHeight=" << targetHeight
-               << ")"
-               << endl;
+               << ")";
 #endif
 
     QRect newRect = transformMatrix.mapRect (pm.rect ());
@@ -295,7 +287,7 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
 
 #endif
 
-    QMatrix scaleMatrix;
+    QTransform scaleMatrix;
     if (targetWidth > 0 && targetWidth != newRect.width ())
     {
     #if DEBUG_KP_PIXMAP_FX && 1
@@ -316,16 +308,21 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
     {
     #if DEBUG_KP_PIXMAP_FX && 1
         // TODO: What is going on here???  Why isn't matrix * working properly?
-        QMatrix wrongMatrix = transformMatrix * scaleMatrix;
-        QMatrix oldHat = transformMatrix;
-        if (targetWidth > 0 && targetWidth != newRect.width ())
+        QTransform wrongMatrix = transformMatrix * scaleMatrix;
+        QTransform oldHat = transformMatrix;
+
+        if (targetWidth > 0 && targetWidth != newRect.width ()) {
             oldHat.scale (double (targetWidth) / double (newRect.width ()), 1);
-        if (targetHeight > 0 && targetHeight != newRect.height ())
+        }
+        if (targetHeight > 0 && targetHeight != newRect.height ()) {
             oldHat.scale (1, double (targetHeight) / double (newRect.height ()));
-        QMatrix altHat = transformMatrix;
+        }
+
+        QTransform altHat = transformMatrix;
+
         altHat.scale ((targetWidth > 0 && targetWidth != newRect.width ()) ? double (targetWidth) / double (newRect.width ()) : 1,
                       (targetHeight > 0 && targetHeight != newRect.height ()) ? double (targetHeight) / double (newRect.height ()) : 1);
-        QMatrix correctMatrix = scaleMatrix * transformMatrix;
+        QTransform correctMatrix = scaleMatrix * transformMatrix;
 
         qCDebug(kpLogPixmapfx) << "\tsupposedlyWrongMatrix: m11=" << wrongMatrix.m11 ()  // <<<---- this is the correct matrix???
                    << " m12=" << wrongMatrix.m12 ()
@@ -334,7 +331,7 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
                    << " dx=" << wrongMatrix.dx ()
                    << " dy=" << wrongMatrix.dy ()
                    << " rect=" << wrongMatrix.mapRect (pm.rect ())
-                   << endl
+                   << "\n"
                    << "\ti_used_to_use_thisMatrix: m11=" << oldHat.m11 ()
                    << " m12=" << oldHat.m12 ()
                    << " m21=" << oldHat.m21 ()
@@ -342,7 +339,7 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
                    << " dx=" << oldHat.dx ()
                    << " dy=" << oldHat.dy ()
                    << " rect=" << oldHat.mapRect (pm.rect ())
-                   << endl
+                   << "\n"
                    << "\tabove but scaled at the same time: m11=" << altHat.m11 ()
                    << " m12=" << altHat.m12 ()
                    << " m21=" << altHat.m21 ()
@@ -350,15 +347,14 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
                    << " dx=" << altHat.dx ()
                    << " dy=" << altHat.dy ()
                    << " rect=" << altHat.mapRect (pm.rect ())
-                   << endl
+                   << "\n"
                    << "\tsupposedlyCorrectMatrix: m11=" << correctMatrix.m11 ()
                    << " m12=" << correctMatrix.m12 ()
                    << " m21=" << correctMatrix.m21 ()
                    << " m22=" << correctMatrix.m22 ()
                    << " dx=" << correctMatrix.dx ()
                    << " dy=" << correctMatrix.dy ()
-                   << " rect=" << correctMatrix.mapRect (pm.rect ())
-                   << endl;
+                   << " rect=" << correctMatrix.mapRect (pm.rect ());
     #endif
 
         transformMatrix = transformMatrix * scaleMatrix;
@@ -393,7 +389,7 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
     //         image is translated 1 pixel off the destination image.
     //
     //         Also, if you skew a rectangular selection, the skewed selection
-    //         border does not line up with the skewed image data. 
+    //         border does not line up with the skewed image data.
     // TODO: do we need to pass <newRect> through this new matrix?
     transformMatrix = ::TrueMatrix (transformMatrix,
         pm.width (), pm.height ());
@@ -417,8 +413,7 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
                    << ",targetWidth=" << targetWidth
                    << ",targetHeight=" << targetHeight
                    << ") newRect=" << newRect
-                   << " (you are a victim of rounding error)"
-                   << endl;
+                   << " (you are a victim of rounding error)";
     #endif
     }
 
@@ -446,20 +441,20 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
     {
         // Make sure transparent pixels are drawn into the destination image.
         p.setCompositionMode (QPainter::CompositionMode_Source);
-    
+
         // Fill the entire new image with the background color.
         if (backgroundColor.isValid ())
         {
             p.fillRect (newQImage.rect (), backgroundColor.toQColor ());
         }
 
-        p.setMatrix (transformMatrix);
+        p.setWorldTransform (transformMatrix);
         p.drawImage (QPoint (0, 0), pm);
     }
     p.end ();
 
 #if DEBUG_KP_PIXMAP_FX && 1
-    qCDebug(kpLogPixmapfx) << "Done" << endl << endl;
+    qCDebug(kpLogPixmapfx) << "Done";
 #endif
 
     return newQImage;
@@ -468,12 +463,12 @@ static QImage TransformPixmap (const QImage &pm, const QMatrix &transformMatrix_
 //---------------------------------------------------------------------
 
 // public static
-QMatrix kpPixmapFX::skewMatrix (int width, int height, double hangle, double vangle)
+QTransform kpPixmapFX::skewMatrix (int width, int height, double hangle, double vangle)
 {
-    if (fabs (hangle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
-        fabs (vangle - 0) < kpPixmapFX::AngleInDegreesEpsilon)
+    if (std::fabs (hangle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
+        std::fabs (vangle - 0) < kpPixmapFX::AngleInDegreesEpsilon)
     {
-        return QMatrix ();
+        return  {};
     }
 
 
@@ -505,11 +500,11 @@ QMatrix kpPixmapFX::skewMatrix (int width, int height, double hangle, double van
      *
      */
 
-    //QMatrix matrix (1, tan (KP_DEGREES_TO_RADIANS (vangle)), tan (KP_DEGREES_TO_RADIANS (hangle)), 1, 0, 0);
+    //QTransform matrix (1, tan (KP_DEGREES_TO_RADIANS (vangle)), tan (KP_DEGREES_TO_RADIANS (hangle)), 1, 0, 0);
     // I think this is clearer than above :)
-    QMatrix matrix;
-    matrix.shear (tan (KP_DEGREES_TO_RADIANS (hangle)),
-                  tan (KP_DEGREES_TO_RADIANS (vangle)));
+    QTransform matrix;
+    matrix.shear (std::tan (qDegreesToRadians (hangle)),
+                  std::tan (qDegreesToRadians (vangle)));
 
     return ::MatrixWithZeroOrigin (matrix, width, height);
 }
@@ -517,7 +512,7 @@ QMatrix kpPixmapFX::skewMatrix (int width, int height, double hangle, double van
 //---------------------------------------------------------------------
 
 // public static
-QMatrix kpPixmapFX::skewMatrix (const QImage &pixmap, double hangle, double vangle)
+QTransform kpPixmapFX::skewMatrix (const QImage &pixmap, double hangle, double vangle)
 {
     return kpPixmapFX::skewMatrix (pixmap.width (), pixmap.height (), hangle, vangle);
 }
@@ -530,8 +525,9 @@ void kpPixmapFX::skew (QImage *destPtr, double hangle, double vangle,
                        const kpColor &backgroundColor,
                        int targetWidth, int targetHeight)
 {
-    if (!destPtr)
+    if (!destPtr) {
         return;
+    }
 
     *destPtr = kpPixmapFX::skew (*destPtr, hangle, vangle,
                                        backgroundColor,
@@ -551,26 +547,25 @@ QImage kpPixmapFX::skew (const QImage &pm, double hangle, double vangle,
                << " hangle=" << hangle
                << " vangle=" << vangle
                << " targetWidth=" << targetWidth
-               << " targetHeight=" << targetHeight
-               << endl;
+               << " targetHeight=" << targetHeight;
 #endif
 
-    if (fabs (hangle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
-        fabs (vangle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
+    if (std::fabs (hangle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
+        std::fabs (vangle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
         (targetWidth <= 0 && targetHeight <= 0)/*don't want to scale?*/)
     {
         return pm;
     }
 
-    if (fabs (hangle) > 90 - kpPixmapFX::AngleInDegreesEpsilon ||
-        fabs (vangle) > 90 - kpPixmapFX::AngleInDegreesEpsilon)
+    if (std::fabs (hangle) > 90 - kpPixmapFX::AngleInDegreesEpsilon ||
+        std::fabs (vangle) > 90 - kpPixmapFX::AngleInDegreesEpsilon)
     {
-        qCCritical(kpLogPixmapfx) << "kpPixmapFX::skew() passed hangle and/or vangle out of range (-90 < x < 90)" << endl;
+        qCCritical(kpLogPixmapfx) << "kpPixmapFX::skew() passed hangle and/or vangle out of range (-90 < x < 90)";
         return pm;
     }
 
 
-    QMatrix matrix = skewMatrix (pm, hangle, vangle);
+    QTransform matrix = skewMatrix (pm, hangle, vangle);
 
     return ::TransformPixmap (pm, matrix, backgroundColor, targetWidth, targetHeight);
 }
@@ -579,14 +574,14 @@ QImage kpPixmapFX::skew (const QImage &pm, double hangle, double vangle,
 
 
 // public static
-QMatrix kpPixmapFX::rotateMatrix (int width, int height, double angle)
+QTransform kpPixmapFX::rotateMatrix (int width, int height, double angle)
 {
-    if (fabs (angle - 0) < kpPixmapFX::AngleInDegreesEpsilon)
+    if (std::fabs (angle - 0) < kpPixmapFX::AngleInDegreesEpsilon)
     {
-        return QMatrix ();
+        return  {};
     }
 
-    QMatrix matrix;
+    QTransform matrix;
     matrix.translate (width / 2, height / 2);
     matrix.rotate (angle);
 
@@ -596,7 +591,7 @@ QMatrix kpPixmapFX::rotateMatrix (int width, int height, double angle)
 //---------------------------------------------------------------------
 
 // public static
-QMatrix kpPixmapFX::rotateMatrix (const QImage &pixmap, double angle)
+QTransform kpPixmapFX::rotateMatrix (const QImage &pixmap, double angle)
 {
     return kpPixmapFX::rotateMatrix (pixmap.width (), pixmap.height (), angle);
 }
@@ -610,18 +605,18 @@ bool kpPixmapFX::isLosslessRotation (double angle)
     const double angleIn = angle;
 
     // Reflect angle into positive if negative
-    if (angle < 0)
+    if (angle < 0) {
         angle = -angle;
+    }
 
     // Remove multiples of 90 to make sure 0 <= angle <= 90
-    angle -= ((int) angle) / 90 * 90;
+    angle -= (static_cast<int> (angle)) / 90 * 90;
 
     // "Impossible" situation?
     if (angle < 0 || angle > 90)
     {
         qCCritical(kpLogPixmapfx) << "kpPixmapFX::isLosslessRotation(" << angleIn
-                   << ") result=" << angle
-                   << endl;
+                   << ") result=" << angle;
         return false;  // better safe than sorry
     }
 
@@ -630,8 +625,7 @@ bool kpPixmapFX::isLosslessRotation (double angle)
 #if DEBUG_KP_PIXMAP_FX
     qCDebug(kpLogPixmapfx) << "kpPixmapFX::isLosslessRotation(" << angleIn << ")"
                << "  residual angle=" << angle
-               << "  returning " << ret
-               << endl;
+               << "  returning " << ret;
 #endif
     return ret;
 }
@@ -644,8 +638,9 @@ void kpPixmapFX::rotate (QImage *destPtr, double angle,
                          const kpColor &backgroundColor,
                          int targetWidth, int targetHeight)
 {
-    if (!destPtr)
+    if (!destPtr) {
         return;
+    }
 
     *destPtr = kpPixmapFX::rotate (*destPtr, angle,
                                          backgroundColor,
@@ -659,14 +654,14 @@ QImage kpPixmapFX::rotate (const QImage &pm, double angle,
                             const kpColor &backgroundColor,
                             int targetWidth, int targetHeight)
 {
-    if (fabs (angle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
+    if (std::fabs (angle - 0) < kpPixmapFX::AngleInDegreesEpsilon &&
         (targetWidth <= 0 && targetHeight <= 0)/*don't want to scale?*/)
     {
         return pm;
     }
 
 
-    QMatrix matrix = rotateMatrix (pm, angle);
+    QTransform matrix = rotateMatrix (pm, angle);
 
     return ::TransformPixmap (pm, matrix, backgroundColor, targetWidth, targetHeight);
 }
