@@ -59,18 +59,22 @@ static void DrawPolygonShape (kpImage *image,
     return;
   }
 
-  if ( bcolor.isValid() )
+  if ( bcolor.isValid() ) {
     painter.setBrush(QBrush(bcolor.toQColor()));
-  else
+  }
+  else {
     painter.setBrush(Qt::NoBrush);
+  }
 
   painter.drawPolygon(points, Qt::OddEvenFill);
 
-  if ( isFinal )
+  if ( isFinal ) {
     return;
+  }
 
-  if ( points.count() <= 2 )
+  if ( points.count() <= 2 ) {
     return;
+  }
 
   painter.setCompositionMode(QPainter::RasterOp_SourceXorDestination);
   painter.setPen(QPen(Qt::white));
@@ -118,10 +122,8 @@ void kpToolPolygon::begin ()
     Q_ASSERT (tb);
 
     d->toolWidgetFillStyle = tb->toolWidgetFillStyle ();
-    connect (d->toolWidgetFillStyle,
-        SIGNAL (fillStyleChanged(kpToolWidgetFillStyle::FillStyle)),
-        this,
-        SLOT (updateShape()));
+    connect (d->toolWidgetFillStyle, &kpToolWidgetFillStyle::fillStyleChanged,
+             this, &kpToolPolygon::updateShape);
     d->toolWidgetFillStyle->show ();
 }
 
@@ -130,10 +132,8 @@ void kpToolPolygon::end ()
 {
     kpToolPolygonalBase::end ();
 
-    disconnect (d->toolWidgetFillStyle,
-        SIGNAL (fillStyleChanged(kpToolWidgetFillStyle::FillStyle)),
-        this,
-        SLOT (updateShape()));
+    disconnect (d->toolWidgetFillStyle, &kpToolWidgetFillStyle::fillStyleChanged,
+                this, &kpToolPolygon::updateShape);
     d->toolWidgetFillStyle = nullptr;
 }
 
@@ -157,15 +157,16 @@ void kpToolPolygon::endDraw (const QPoint &, const QRect &)
 {
 #if DEBUG_KP_TOOL_POLYGON
     qCDebug(kpLogTools) << "kpToolPolygon::endDraw()  points="
-        << points ()->toList () << endl;
+        << points ()->toList ();
 #endif
 
     // A click of the other mouse button (to finish shape, instead of adding
     // another control point) would have caused endShape() to have been
     // called in kpToolPolygonalBase::beginDraw().  The points list would now
     // be empty.  We are being called by kpTool::mouseReleaseEvent().
-    if (points ()->count () == 0)
+    if (points ()->count () == 0) {
         return;
+    }
 
     if (points ()->count () >= kpToolPolygonalBase::MaxPoints)
     {
