@@ -52,9 +52,7 @@ kpToolFreeFormSelection::kpToolFreeFormSelection (kpToolSelectionEnvironment *en
 
 //---------------------------------------------------------------------
 
-kpToolFreeFormSelection::~kpToolFreeFormSelection ()
-{
-}
+kpToolFreeFormSelection::~kpToolFreeFormSelection () = default;
 
 //---------------------------------------------------------------------
 
@@ -68,7 +66,7 @@ bool kpToolFreeFormSelection::drawCreateMoreSelectionAndUpdateStatusBar (
     qCDebug(kpLogTools) << "kpToolFreeFormSelection::createMoreSelectionAndUpdateStatusBar("
                << "dragAccepted=" << dragAccepted
                << ",accidentalDragAdjustedPoint=" << accidentalDragAdjustedPoint
-               << ")" << endl;
+               << ")";
 #endif
 
     // Prevent unintentional creation of 1-pixel selections.
@@ -82,14 +80,14 @@ bool kpToolFreeFormSelection::drawCreateMoreSelectionAndUpdateStatusBar (
     }
 
     Q_ASSERT (accidentalDragAdjustedPoint == currentPoint ());
-    Q_ASSERT (dragAccepted == (bool) document ()->selection ());
+    Q_ASSERT (dragAccepted == static_cast<bool> (document ()->selection ()));
 
     const kpFreeFormImageSelection *oldPointsSel = nullptr;
     if (document ()->selection ())
     {
         kpAbstractSelection *sel = document ()->selection ();
         Q_ASSERT (dynamic_cast <kpFreeFormImageSelection *> (sel));
-        oldPointsSel = static_cast <kpFreeFormImageSelection *> (sel);
+        oldPointsSel = dynamic_cast <kpFreeFormImageSelection *> (sel);
     }
 
 
@@ -103,8 +101,9 @@ bool kpToolFreeFormSelection::drawCreateMoreSelectionAndUpdateStatusBar (
     // Not first point in drag.
     else
     {
-      if ( !oldPointsSel )  // assert above says we never reach this, but let's make coverity happy
-        return false;
+        if ( !oldPointsSel ) {  // assert above says we never reach this, but let's make coverity happy
+            return false;
+        }
 
       // Get existing points in selection.
       points = oldPointsSel->cardinallyAdjacentPoints ();
@@ -129,8 +128,7 @@ bool kpToolFreeFormSelection::drawCreateMoreSelectionAndUpdateStatusBar (
 
 #if DEBUG_KP_TOOL_FREE_FROM_SELECTION && 1
     qCDebug(kpLogTools) << "\t\tfreeform; #points="
-              << document ()->selection ()->calculatePoints ().count ()
-              << endl;
+              << document ()->selection ()->calculatePoints ().count ();
 #endif
 
     setUserShapePoints (accidentalDragAdjustedPoint);
