@@ -38,13 +38,13 @@
 #include <ksharedconfig.h>
 #include "kpLogCategories.h"
 
-#include <qbitmap.h>
-#include <qcolor.h>
-#include <qevent.h>
+#include <QBitmap>
+#include <QColor>
+#include <QEvent>
 #include <QHelpEvent>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpixmap.h>
+#include <QImage>
+#include <QPainter>
+#include <QPixmap>
 #include <QToolTip>
 
 
@@ -64,17 +64,16 @@ kpToolWidgetBase::kpToolWidgetBase (QWidget *parent, const QString &name)
 
 //---------------------------------------------------------------------
 
-kpToolWidgetBase::~kpToolWidgetBase ()
-{
-}
+kpToolWidgetBase::~kpToolWidgetBase () = default;
 
 //---------------------------------------------------------------------
 
 // public
 void kpToolWidgetBase::addOption (const QPixmap &pixmap, const QString &toolTip)
 {
-    if (m_pixmaps.isEmpty ())
+    if (m_pixmaps.isEmpty ()) {
         startNewOptionRow ();
+    }
 
     m_pixmaps.last ().append (pixmap);
     m_pixmapRects.last ().append (QRect ());
@@ -100,8 +99,7 @@ void kpToolWidgetBase::finishConstruction (int fallBackRow, int fallBackCol)
     qCDebug(kpLogWidgets) << "kpToolWidgetBase(" << objectName ()
                << ")::kpToolWidgetBase(fallBack:row=" << fallBackRow
                << ",col=" << fallBackCol
-               << ")"
-               << endl;
+               << ")";
 #endif
 
     relayoutOptions ();
@@ -125,7 +123,7 @@ void kpToolWidgetBase::finishConstruction (int fallBackRow, int fallBackCol)
             if (!setSelected (0, 0))
             {
                 qCCritical(kpLogWidgets) << "kpToolWidgetBase::finishConstruction() "
-                              "can't even fall back to setSelected(row=0,col=0)" << endl;
+                              "can't even fall back to setSelected(row=0,col=0)";
             }
         }
     }
@@ -136,9 +134,11 @@ void kpToolWidgetBase::finishConstruction (int fallBackRow, int fallBackCol)
 // private
 QList <int> kpToolWidgetBase::spreadOutElements (const QList <int> &sizes, int max)
 {
-    if (sizes.count () == 0)
+    if (sizes.count () == 0) {
         return QList <int> ();
-    else if (sizes.count () == 1)
+    }
+
+    if (sizes.count () == 1)
     {
         QList <int> ret;
         ret.append (sizes.first () > max ? 0 : 1/*margin*/);
@@ -146,12 +146,14 @@ QList <int> kpToolWidgetBase::spreadOutElements (const QList <int> &sizes, int m
     }
 
     QList <int> retOffsets;
-    for (int i = 0; i < sizes.count (); i++)
+    for (int i = 0; i < sizes.count (); i++) {
         retOffsets.append (0);
+    }
 
     int totalSize = 0;
-    for (int i = 0; i < (int) sizes.count (); i++)
+    for (int i = 0; i <  sizes.count (); i++) {
         totalSize += sizes [i];
+    }
 
     int margin = 1;
 
@@ -160,8 +162,9 @@ QList <int> kpToolWidgetBase::spreadOutElements (const QList <int> &sizes, int m
     if (totalSize + margin * 2 > max)
     {
         retOffsets [0] = 0;
-        for (int i = 1; i < (int) sizes.count (); i++)
+        for (int i = 1; i < sizes.count (); i++) {
             retOffsets [i] = retOffsets [i - 1] + sizes [i - 1];
+        }
 
         return retOffsets;
     }
@@ -181,7 +184,7 @@ QList <int> kpToolWidgetBase::spreadOutElements (const QList <int> &sizes, int m
     }
 
     retOffsets [0] = margin;
-    for (int i = 1; i < (int) sizes.count (); i++)
+    for (int i = 1; i < sizes.count (); i++)
     {
         retOffsets [i] += retOffsets [i - 1] +
                           sizes [i - 1] +
@@ -212,8 +215,7 @@ QPair <int, int> kpToolWidgetBase::defaultSelectedRowAndCol () const
 #if DEBUG_KP_TOOL_WIDGET_BASE
     qCDebug(kpLogWidgets) << "kpToolWidgetBase(" << objectName ()
                << ")::defaultSelectedRowAndCol() returning row=" << row
-               << " col=" << col
-               << endl;
+               << " col=" << col;
 #endif
 
     return qMakePair (row, col);
@@ -243,11 +245,12 @@ void kpToolWidgetBase::saveSelectedAsDefault () const
 #if DEBUG_KP_TOOL_WIDGET_BASE
     qCDebug(kpLogWidgets) << "kpToolWidgetBase(" << objectName ()
                << ")::saveSelectedAsDefault() row=" << m_selectedRow
-               << " col=" << m_selectedCol << endl;
+               << " col=" << m_selectedCol;
 #endif
 
-    if (objectName ().isEmpty ())
+    if (objectName ().isEmpty ()) {
         return;
+    }
 
     KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupTools);
 
@@ -275,8 +278,9 @@ void kpToolWidgetBase::relayoutOptions ()
         m_toolTips.removeLast ();
     }
 
-    if (m_pixmaps.isEmpty ())
+    if (m_pixmaps.isEmpty ()) {
         return;
+    }
 
 #if DEBUG_KP_TOOL_WIDGET_BASE
     qCDebug(kpLogWidgets) << "\tsurvived killing of empty rows";
@@ -284,15 +288,17 @@ void kpToolWidgetBase::relayoutOptions ()
 #endif
 
     QList <int> maxHeightOfRow;
-    for (int r = 0; r < m_pixmaps.count (); r++)
+    for (int r = 0; r < m_pixmaps.count (); r++) {
         maxHeightOfRow.append (0);
+    }
 
-    for (int r = 0; r < (int) m_pixmaps.count (); r++)
+    for (int r = 0; r <  m_pixmaps.count (); r++)
     {
-        for (int c = 0; c < (int) m_pixmaps [r].count (); c++)
+        for (int c = 0; c <  m_pixmaps [r].count (); c++)
         {
-            if (c == 0 || m_pixmaps [r][c].height () > maxHeightOfRow [r])
+            if (c == 0 || m_pixmaps [r][c].height () > maxHeightOfRow [r]) {
                 maxHeightOfRow [r] = m_pixmaps [r][c].height ();
+            }
         }
     #if DEBUG_KP_TOOL_WIDGET_BASE
         qCDebug(kpLogWidgets) << "\t\t" << r << ": " << maxHeightOfRow [r];
@@ -302,57 +308,66 @@ void kpToolWidgetBase::relayoutOptions ()
     QList <int> rowYOffset = spreadOutElements (maxHeightOfRow, height ());
 #if DEBUG_KP_TOOL_WIDGET_BASE
     qCDebug(kpLogWidgets) << "\tspread out offsets of rows:";
-    for (int r = 0; r < (int) rowYOffset.count (); r++)
+    for (int r = 0; r < (int) rowYOffset.count (); r++) {
         qCDebug(kpLogWidgets) << "\t\t" << r << ": " << rowYOffset [r];
+    }
 #endif
 
-    for (int r = 0; r < (int) m_pixmaps.count (); r++)
+    for (int r = 0; r < m_pixmaps.count (); r++)
     {
     #if DEBUG_KP_TOOL_WIDGET_BASE
         qCDebug(kpLogWidgets) << "\tlaying out row " << r << ":";
     #endif
 
         QList <int> widths;
-        for (int c = 0; c < (int) m_pixmaps [r].count (); c++)
+        for (int c = 0; c < m_pixmaps [r].count (); c++)
             widths.append (m_pixmaps [r][c].width ());
     #if DEBUG_KP_TOOL_WIDGET_BASE
         qCDebug(kpLogWidgets) << "\t\twidths of cols:";
-        for (int c = 0; c < (int) m_pixmaps [r].count (); c++)
+        for (int c = 0; c <  m_pixmaps [r].count (); c++) {
             qCDebug(kpLogWidgets) << "\t\t\t" << c << ": " << widths [c];
+        }
     #endif
 
         QList <int> colXOffset = spreadOutElements (widths, width ());
     #if DEBUG_KP_TOOL_WIDGET_BASE
         qCDebug(kpLogWidgets) << "\t\tspread out offsets of cols:";
-        for (int c = 0; c < (int) colXOffset.count (); c++)
+        for (int c = 0; c < colXOffset.count (); c++) {
             qCDebug(kpLogWidgets) << "\t\t\t" << c << ": " << colXOffset [c];
+        }
     #endif
 
-        for (int c = 0; c < (int) colXOffset.count (); c++)
+        for (int c = 0; c < colXOffset.count (); c++)
         {
             int x = colXOffset [c];
             int y = rowYOffset [r];
             int w, h;
 
-            if (c == (int) colXOffset.count () - 1)
+            if (c == colXOffset.count () - 1)
             {
-                if (x + m_pixmaps [r][c].width () >= width ())
+                if (x + m_pixmaps [r][c].width () >= width ()) {
                     w = m_pixmaps [r][c].width ();
-                else
+                }
+                else {
                     w = width () - 1 - x;
+                }
             }
-            else
+            else {
                 w = colXOffset [c + 1] - x;
-
-            if (r == (int) m_pixmaps.count () - 1)
-            {
-                if (y + m_pixmaps [r][c].height () >= height ())
-                    h = m_pixmaps [r][c].height ();
-                else
-                    h = height () - 1 - y;
             }
-            else
+
+            if (r == m_pixmaps.count () - 1)
+            {
+                if (y + m_pixmaps [r][c].height () >= height ()) {
+                    h = m_pixmaps [r][c].height ();
+                }
+                else {
+                    h = height () - 1 - y;
+                }
+            }
+            else {
                 h = rowYOffset [r + 1] - y;
+            }
 
             m_pixmapRects [r][c] = QRect (x, y, w, h);
         }
@@ -384,18 +399,20 @@ int kpToolWidgetBase::selectedCol () const
 int kpToolWidgetBase::selected () const
 {
     if (m_selectedRow < 0 ||
-        m_selectedRow >= (int) m_pixmaps.count () ||
+        m_selectedRow >= m_pixmaps.count () ||
         m_selectedCol < 0)
     {
         return -1;
     }
 
     int upto = 0;
-    for (int y = 0; y < m_selectedRow; y++)
+    for (int y = 0; y < m_selectedRow; y++) {
         upto += m_pixmaps [y].count ();
+    }
 
-    if (m_selectedCol >= (int) m_pixmaps [m_selectedRow].count ())
+    if (m_selectedCol >= m_pixmaps [m_selectedRow].count ()) {
         return -1;
+    }
 
     upto += m_selectedCol;
 
@@ -411,17 +428,19 @@ bool kpToolWidgetBase::hasPreviousOption (int *row, int *col) const
 #if DEBUG_KP_TOOL_WIDGET_BASE
     qCDebug(kpLogWidgets) << "kpToolWidgetBase(" << objectName ()
                << ")::hasPreviousOption() current row=" << m_selectedRow
-               << " col=" << m_selectedCol
-               << endl;
+               << " col=" << m_selectedCol;
 #endif
-    if (row)
+    if (row) {
         *row = -1;
-    if (col)
+    }
+    if (col) {
         *col = -1;
+    }
 
 
-    if (m_selectedRow < 0 || m_selectedCol < 0)
+    if (m_selectedRow < 0 || m_selectedCol < 0) {
         return false;
+    }
 
     int newRow = m_selectedRow,
         newCol = m_selectedCol;
@@ -430,19 +449,23 @@ bool kpToolWidgetBase::hasPreviousOption (int *row, int *col) const
     if (newCol < 0)
     {
         newRow--;
-        if (newRow < 0)
+        if (newRow < 0) {
             return false;
+        }
 
         newCol = m_pixmaps [newRow].count () - 1;
-        if (newCol < 0)
+        if (newCol < 0) {
             return false;
+        }
     }
 
 
-    if (row)
+    if (row) {
         *row = newRow;
-    if (col)
+    }
+    if (col) {
         *col = newCol;
+    }
 
     return true;
 }
@@ -455,39 +478,45 @@ bool kpToolWidgetBase::hasNextOption (int *row, int *col) const
 #if DEBUG_KP_TOOL_WIDGET_BASE
     qCDebug(kpLogWidgets) << "kpToolWidgetBase(" << objectName ()
                << ")::hasNextOption() current row=" << m_selectedRow
-               << " col=" << m_selectedCol
-               << endl;
+               << " col=" << m_selectedCol;
 #endif
 
-    if (row)
+    if (row) {
         *row = -1;
-    if (col)
+    }
+    if (col) {
         *col = -1;
+    }
 
 
-    if (m_selectedRow < 0 || m_selectedCol < 0)
+    if (m_selectedRow < 0 || m_selectedCol < 0) {
         return false;
+    }
 
     int newRow = m_selectedRow,
         newCol = m_selectedCol;
 
     newCol++;
-    if (newCol >= (int) m_pixmaps [newRow].count ())
+    if (newCol >= m_pixmaps [newRow].count ())
     {
         newRow++;
-        if (newRow >= (int) m_pixmaps.count ())
+        if (newRow >= m_pixmaps.count ()) {
             return false;
+        }
 
         newCol = 0;
-        if (newCol >= (int) m_pixmaps [newRow].count ())
+        if (newCol >= m_pixmaps [newRow].count ()) {
             return false;
+        }
     }
 
 
-    if (row)
+    if (row) {
         *row = newRow;
-    if (col)
+    }
+    if (col) {
         *col = newCol;
+    }
 
     return true;
 }
@@ -502,12 +531,11 @@ bool kpToolWidgetBase::setSelected (int row, int col, bool saveAsDefault)
     qCDebug(kpLogWidgets) << "kpToolWidgetBase::setSelected(row=" << row
                << ",col=" << col
                << ",saveAsDefault=" << saveAsDefault
-               << ")"
-               << endl;
+               << ")";
 #endif
 
     if (row < 0 || col < 0 ||
-        row >= (int) m_pixmapRects.count () || col >= (int) m_pixmapRects [row].count ())
+        row >= m_pixmapRects.count () || col >= m_pixmapRects [row].count ())
     {
     #if DEBUG_KP_TOOL_WIDGET_BASE
         qCDebug(kpLogWidgets) << "\tout of range";
@@ -521,8 +549,9 @@ bool kpToolWidgetBase::setSelected (int row, int col, bool saveAsDefault)
         qCDebug(kpLogWidgets) << "\tNOP";
     #endif
 
-        if (saveAsDefault)
+        if (saveAsDefault) {
             saveSelectedAsDefault ();
+        }
 
         return true;
     }
@@ -530,7 +559,8 @@ bool kpToolWidgetBase::setSelected (int row, int col, bool saveAsDefault)
     const int wasSelectedRow = m_selectedRow;
     const int wasSelectedCol = m_selectedCol;
 
-    m_selectedRow = row, m_selectedCol = col;
+    m_selectedRow = row;
+    m_selectedCol = col;
 
     if (wasSelectedRow >= 0 && wasSelectedCol >= 0)
     {
@@ -545,8 +575,9 @@ bool kpToolWidgetBase::setSelected (int row, int col, bool saveAsDefault)
     qCDebug(kpLogWidgets) << "\tOK";
 #endif
 
-    if (saveAsDefault)
+    if (saveAsDefault) {
         saveSelectedAsDefault ();
+    }
 
     emit optionSelected (row, col);
     return true;
@@ -567,8 +598,9 @@ bool kpToolWidgetBase::setSelected (int row, int col)
 bool kpToolWidgetBase::selectPreviousOption ()
 {
     int newRow, newCol;
-    if (!hasPreviousOption (&newRow, &newCol))
+    if (!hasPreviousOption (&newRow, &newCol)) {
         return false;
+    }
 
     return setSelected (newRow, newCol);
 }
@@ -579,8 +611,9 @@ bool kpToolWidgetBase::selectPreviousOption ()
 bool kpToolWidgetBase::selectNextOption ()
 {
     int newRow, newCol;
-    if (!hasNextOption (&newRow, &newCol))
+    if (!hasNextOption (&newRow, &newCol)) {
         return false;
+    }
 
     return setSelected (newRow, newCol);
 }
@@ -597,22 +630,22 @@ bool kpToolWidgetBase::event (QEvent *e)
     //       its base which calls ignore() :)
     if (e->type () == QEvent::ToolTip)
     {
-        QHelpEvent *he = (QHelpEvent *) e;
+        auto *he = dynamic_cast<QHelpEvent *> (e);
     #if DEBUG_KP_TOOL_WIDGET_BASE
         qCDebug(kpLogWidgets) << "kpToolWidgetBase::event() QHelpEvent pos=" << he->pos ();
     #endif
 
         bool showedText = false;
-        for (int r = 0; r < (int) m_pixmapRects.count (); r++)
+        for (int r = 0; r < m_pixmapRects.count (); r++)
         {
-            for (int c = 0; c < (int) m_pixmapRects [r].count (); c++)
+            for (int c = 0; c < m_pixmapRects [r].count (); c++)
             {
                 if (m_pixmapRects [r][c].contains (he->pos ()))
                 {
                     const QString tip = m_toolTips [r][c];
                 #if DEBUG_KP_TOOL_WIDGET_BASE
                     qCDebug(kpLogWidgets) << "\tin option: r=" << r << "c=" << c
-                              << "tip='" << tip << "'" << endl;
+                              << "tip='" << tip << "'";
                 #endif                
                     if (!tip.isEmpty ())
                     {
@@ -637,8 +670,8 @@ bool kpToolWidgetBase::event (QEvent *e)
 
         return true;
     }
-    else
-        return QWidget::event (e);
+
+    return QWidget::event (e);
 }
 
 //---------------------------------------------------------------------
@@ -649,13 +682,14 @@ void kpToolWidgetBase::mousePressEvent (QMouseEvent *e)
 {
     e->ignore ();
 
-    if (e->button () != Qt::LeftButton)
+    if (e->button () != Qt::LeftButton) {
         return;
+    }
 
 
-    for (int i = 0; i < (int) m_pixmapRects.count (); i++)
+    for (int i = 0; i < m_pixmapRects.count (); i++)
     {
-        for (int j = 0; j < (int) m_pixmapRects [i].count (); j++)
+        for (int j = 0; j < m_pixmapRects [i].count (); j++)
         {
             if (m_pixmapRects [i][j].contains (e->pos ()))
             {
@@ -681,13 +715,13 @@ void kpToolWidgetBase::paintEvent (QPaintEvent *e)
 
     QPainter painter (this);
 
-    for (int i = 0; i < (int) m_pixmaps.count (); i++)
+    for (int i = 0; i < m_pixmaps.count (); i++)
     {
         #if DEBUG_KP_TOOL_WIDGET_BASE && 1
             qCDebug(kpLogWidgets) << "\tRow: " << i;
         #endif
 
-        for (int j = 0; j < (int) m_pixmaps [i].count (); j++)
+        for (int j = 0; j < m_pixmaps [i].count (); j++)
         {
             QRect rect = m_pixmapRects [i][j];
             QPixmap pixmap = m_pixmaps [i][j];
@@ -705,8 +739,7 @@ void kpToolWidgetBase::paintEvent (QPaintEvent *e)
             qCDebug(kpLogWidgets) << "\t\t\tdraw pixmap @ x="
                        << rect.x () + (rect.width () - pixmap.width ()) / 2
                        << " y="
-                       << rect.y () + (rect.height () - pixmap.height ()) / 2
-                       << endl;
+                       << rect.y () + (rect.height () - pixmap.height ()) / 2;
 
         #endif
 
